package com.zoniot.readingmeter.service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.zoniot.readingmeter.model.ResponseMessage;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RequestCallback;
import org.springframework.web.client.ResponseExtractor;
import org.springframework.web.client.RestTemplate;

import java.util.HashMap;
import java.util.Map;

@Slf4j
@Component
public class OptService {
    private RestTemplate restTemplate = new RestTemplate();
    @Value("${water-cloud-url}")
    String apiUrl;
    @Autowired
    private AccessTokenService accessTokenService;

    public ResponseMessage valveControl(String meterNo, String valve){

        ResponseMessage responseMessage = new ResponseMessage();

        String accessToken = accessTokenService.getAccessToken();

        log.info("accessToken={}",accessToken);
        String tokenUrl = apiUrl + "/api/meter/valve/control";
        log.info("tokenUrl={}",tokenUrl);
        //log.info("postData : {}", JSON.toJSONString(deviceReplace));
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON_UTF8);
        headers.add("Authorization", "Bearer " + accessToken);

        Map<String,String> map = new HashMap<>();
        map.put("meterNo",meterNo);
        map.put("valve",valve);
        String content = JSON.toJSONString(map);

        log.info("content={}",content);
        HttpEntity<String> request = new HttpEntity<>(content,headers);

        ResponseEntity<String> responseEntity = null;
        try {

            RequestCallback requestCallback = restTemplate.httpEntityCallback(request, JSONObject.class);
            ResponseExtractor<ResponseEntity<String>> responseExtractor = restTemplate.responseEntityExtractor(String.class);
            responseEntity = restTemplate.execute(tokenUrl, HttpMethod.POST,requestCallback,responseExtractor);
        }catch (Exception e){
            log.error("request error e={}",e.getMessage());
            responseMessage.setSuccess("0");
            responseMessage.setMessage(e.getMessage());
        }
        if (responseEntity != null) {
            //log.info("responseEntity : {}", responseEntity);
            log.info("responseEntity : {} {}", responseEntity.getStatusCodeValue(),responseEntity.getBody());
            JSONObject jsonObj = (JSONObject) JSONObject.parse(responseEntity.getBody());
            Integer status = jsonObj.getInteger("status");
            if (status==0) {
                responseMessage.setSuccess("1");
            }else {
                responseMessage.setSuccess("0");
                responseMessage.setMessage(jsonObj.getString("msg"));
            }

            return responseMessage;
        }else {
            responseMessage.setSuccess("0");
        }
        return responseMessage;
    }
}
